@@ -11,7 +11,7 @@ from getpass import getpass
 from hashlib import md5
 from json import dump, load
 from os import path, makedirs, getcwd, access, W_OK, X_OK
-from sys import argv, stdout
+from sys import argv
 from RDWorker import RDWorker, UnrestrictionError
 from urllib2 import HTTPCookieProcessor, build_opener
 
@@ -29,13 +29,15 @@ def usage(status=0):
     print '  -l\tList. Write a list of the successfully unrestricted links on STDOUT, without downloading.'
     print '\t-t and -q options have no effect if -l is used.'
     print '  -o\tOutput directory. Download files into a specific directory.'
+    print '  -O\tOutput file. Specify a name for the downloaded file instead of using the original file\'s name.'
+    print '\t-O has no effect if several files will be downloaded.'
     print '  -p\tPassword. Provide a password for protected downloads.'
     print '  -q\tQuiet mode. No output will be generated.'
     print '  -t\tTest mode. Perform all operations EXCEPT file downloading.'
     # print '  -T\tTimeout. The maximum number of seconds to wait for a download to start.'
 
-    print '\nLINK can be set of URLs to files you want to download (i.e. http://host.com/myFile.zip) ' \
-          'or the path to a file containing them.'
+    print '\n`LINK` can be the URL to a file you want to download (i.e. http://host.com/myFile.zip) or the path to a ' \
+          'file containing one ore several URL(s).'
 
     print '\nExample: rdcli http://host.com/myFile.zip'
     print 'Example: rdcli urls.txt'
@@ -98,7 +100,7 @@ def main():
 
     # parse command-line arguments
     try:
-        opts, args = gnu_getopt(argv[1:], 'hiqtlp:o:T:')
+        opts, args = gnu_getopt(argv[1:], 'hiqtlp:o:T:O:')
     except GetoptError as e:
         print str(e)
         usage(1)
@@ -125,6 +127,8 @@ def main():
             download_password = argument
         elif option == '-T':
             timeout = int(argument)
+        elif option == '-O':
+            filename = argument
 
     # stop now if no download and no output wanted
     if test and not verbose:
@@ -172,13 +176,20 @@ def main():
             debug('\nUnrestricting %s' % link)
 
             try:
-                unrestricted, filename = worker.unrestrict(link, download_password)
+                unrestricted, original_filename = worker.unrestrict(link, download_password)
                 debug(u'→ ' + unrestricted + '\n')
 
                 if list_only:
                     print unrestricted
                 elif not test:
-                    fullpath = path.join(output_dir, filename)
+
+                    if len(links) == 1:
+                        try:
+                            fullpath = path.join(output_dir, filename)
+                        except NameError:
+                            fullpath = path.join(output_dir, original_filename)
+                    else:
+                        fullpath = path.join(output_dir, original_filename)
 
                     try:
                         to_mb = lambda b: b / 1048576.
